@@ -1,6 +1,6 @@
 from maggma.api.query_operator import QueryOperator
 from maggma.api.utils import STORE_PARAMS
-from emmet.api.routes.tasks.utils import calcs_reversed_to_trajectory
+from emmet.api.routes.tasks.utils import calcs_reversed_to_trajectory, task_to_entry
 from fastapi import Query
 from typing import Optional
 from monty.json import jsanitize
@@ -12,13 +12,22 @@ class MultipleTaskIDsQuery(QueryOperator):
     """
 
     def query(
-        self, task_ids: Optional[str] = Query(None, description="Comma-separated list of task_ids to query on"),
+        self,
+        task_ids: Optional[str] = Query(
+            None, description="Comma-separated list of task_ids to query on"
+        ),
     ) -> STORE_PARAMS:
 
         crit = {}
 
         if task_ids:
-            crit.update({"task_id": {"$in": [task_id.strip() for task_id in task_ids.split(",")]}})
+            crit.update(
+                {
+                    "task_id": {
+                        "$in": [task_id.strip() for task_id in task_ids.split(",")]
+                    }
+                }
+            )
 
         return {"criteria": crit}
 
@@ -29,13 +38,22 @@ class TrajectoryQuery(QueryOperator):
     """
 
     def query(
-        self, task_ids: Optional[str] = Query(None, description="Comma-separated list of task_ids to query on"),
+        self,
+        task_ids: Optional[str] = Query(
+            None, description="Comma-separated list of task_ids to query on"
+        ),
     ) -> STORE_PARAMS:
 
         crit = {}
 
         if task_ids:
-            crit.update({"task_id": {"$in": [task_id.strip() for task_id in task_ids.split(",")]}})
+            crit.update(
+                {
+                    "task_id": {
+                        "$in": [task_id.strip() for task_id in task_ids.split(",")]
+                    }
+                }
+            )
 
         return {"criteria": crit}
 
@@ -45,7 +63,50 @@ class TrajectoryQuery(QueryOperator):
         """
 
         d = [
-            {"task_id": doc["task_id"], "trajectories": jsanitize(calcs_reversed_to_trajectory(doc["calcs_reversed"]))}
+            {
+                "task_id": doc["task_id"],
+                "trajectories": jsanitize(
+                    calcs_reversed_to_trajectory(doc["calcs_reversed"])
+                ),
+            }
+            for doc in docs
+        ]
+
+        return d
+
+
+class EntryQuery(QueryOperator):
+    """
+    Method to generate a query on calculation entry data from task documents
+    """
+
+    def query(
+        self,
+        task_ids: Optional[str] = Query(
+            None, description="Comma-separated list of task_ids to query on"
+        ),
+    ) -> STORE_PARAMS:
+
+        crit = {}
+
+        if task_ids:
+            crit.update(
+                {
+                    "task_id": {
+                        "$in": [task_id.strip() for task_id in task_ids.split(",")]
+                    }
+                }
+            )
+
+        return {"criteria": crit}
+
+    def post_process(self, docs, query):
+        """
+        Post processing to generatore entry data
+        """
+
+        d = [
+            {"task_id": doc["task_id"], "entry": jsanitize(task_to_entry(doc))}
             for doc in docs
         ]
 
@@ -58,7 +119,10 @@ class DeprecationQuery(QueryOperator):
     """
 
     def query(
-        self, task_ids: str = Query(..., description="Comma-separated list of task_ids to query on"),
+        self,
+        task_ids: str = Query(
+            ..., description="Comma-separated list of task_ids to query on"
+        ),
     ) -> STORE_PARAMS:
 
         self.task_ids = [task_id.strip() for task_id in task_ids.split(",")]
